SystemOrganization addCategory: #'DAO-SatelliteTests'!

TestCase subclass: #CommandParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:32'!
testDeserializeNegativeSigned16BitInteger
	| serializedValue parameter streamDeLectura |
	
	serializedValue := #[1 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: -1.! !

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:35'!
testDeserializePositiveSigned16BitInteger
| serializedValue parameter streamDeLectura |
	
	serializedValue := #[0 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: 1.! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:31'!
testSerializeString8
	| parameter |
	
	parameter := StringCommandParameter new: 8.
	parameter value: 'Hello'.
	
	self assert: (parameter serialize) equals: #[5 72 101 108 108 111].! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:27'!
testSerializeUnsigned32BitInteger
	| parameter |
	
	parameter := UnsignedIntegerCommandParameter new: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 16:54'!
thermalSubsystemNameCommand

	^  GetNameCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 0.
	
! !

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 16:57'!
thermalSubsystemTelemetryCommand

	^  ThermalTelemetryCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 1.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 18:09'!
testDeserializingArrayOfUnsigned8BitIntegerShouldReturnTheDecodedArray

	| encodedResponse decodedResponse readAddressCommand array |
	
	"setup"
	"001 sequence number, 1 first byte, 2 second"
	encodedResponse := #[0 0 1 1 2].

	readAddressCommand := MemoryReadAddressCommand new.
	
	"exercise"	
	decodedResponse := readAddressCommand deserialize: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 1.
	
	array := (decodedResponse data at: 1).
	
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 19:46'!
testDeserializingThermalNameResponseShouldReturnThermal

	| encodedResponse decodedResponse getNameCommand |

	"001 sequence number, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 84 72 69 82 77 65 76].
	
	getNameCommand := GetNameCommand new.
	
	decodedResponse := getNameCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data size) equals: 1.
	self assert: (decodedResponse data at: 1) equals: 'THERMAL'.! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 19:53'!
testDeserializingThermalSetMatrixKeyResponseShouldReturnVoid

	| encodedResponse thermalSetMatrixKeyCommand decodedResponse |
	
	"001 sequence number, then empty response"
	encodedResponse := #[0 0 1].
	
	thermalSetMatrixKeyCommand :=  ThermalSetMatrixKeyCommand new.
	
	decodedResponse :=  thermalSetMatrixKeyCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse class) equals: VoidCommandResponse.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 20:37'!
testDeserializingThermalShortTelemetryResponseShouldReturnThermalShortTelemetry

	| encodedResponse thermalShortTelemetryCommand decodedResponse |
	
	"001 sequence number, 1 battery temp"
	encodedResponse := #[0 0 1 1].
	thermalShortTelemetryCommand :=  ThermalShortTelemetryCommand new.
	
	decodedResponse :=  thermalShortTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 15:06'!
testDeserializingThermalTelemetryResponseContainingNegativeNumbersShouldDeserializeOK

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 1 1 battery temp, 1 2 radio temp"
	encodedResponse := #[0 0 1 1 1 1 2].

	thermalTelemetryCommand := ThermalTelemetryCommand new.
		
	decodedResponse := thermalTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: -1.
	self assert: (decodedResponse data at: 2) equals: -2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 15:03'!
testDeserializingThermalTelemetryResponseShouldReturnThermalTelemetry

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 0 1 battery temp, 0 2 radio temp"
	encodedResponse := #[0 0 1 0 1 0 2].

	thermalTelemetryCommand := ThermalTelemetryCommand new.
		
	decodedResponse := thermalTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	self assert: (decodedResponse data at: 2) equals: 2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 18:19'!
testDeserializingUsigned32BitIntegerAndArrayOfUnsigned8BitIntegerShouldDeserializeOK

	| encodedResponse decodedResponse readLongAddressCommand array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	readLongAddressCommand := MemoryReadLongAddressCommand new.
	
	"exercise"	
	decodedResponse := readLongAddressCommand deserialize: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'execution' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 20:38'!
testSendingNameCommandToThermalSubsystem
	| thermalSubsystem command response |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := GetNameCommand newWithReceiver: thermalSubsystem andId: 0.
	
	"exercise"
	response := command execute.
	
	"verify"
	self assert: (response message) equals: 'THERMAL'! !

!CommandTest methodsFor: 'execution' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSendingSetMatrixKeyCommandToThermalSubsystem
	| thermalSubsystem command response voidResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := ThermalSetMatrixKeyCommand newWithReceiver: thermalSubsystem andId: 0.
	voidResponse := VoidCommandResponse new.	
	"exercise"
	command addParameterValue: 10.
	response := command execute.
	"verify"
	self assert: response equals: voidResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSerializingCommandWithFiveU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadChunkedAddressCommand newWithReceiver: SatelliteTest memorySubsystem andId: 45.

	command addParameterValue: 1.
	command addParameterValue: 2.
	command addParameterValue: 3.
	command addParameterValue: 4.
	command addParameterValue: 5.
	
	self assert: command serialize equals: #[45 0 0 0 1 0 0 0 2 0 0 0 3 0 0 0 4 0 0 0 5]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:54'!
testSerializingCommandWithMaxValueSetToOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := PowerStbSetSwitchesStateCommand newWithReceiver: SatelliteTest powerSubsystem andId: 36.

	command addParameterValue: 16777215.
	
	self assert: command serialize equals: #[36 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:40'!
testSerializingCommandWithMaxValueSetToOneU8ParameterShouldSerializeOK
	
	| command |
	
	command := PlatformSetModeCommand newWithReceiver: SatelliteTest platformSubsystem andId: 32.

	command addParameterValue: 255.
	
	self assert: command serialize equals: #[32 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSerializingCommandWithMaxValuesSetToTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadLongAddressCommand newWithReceiver: SatelliteTest memorySubsystem andId: 44.

	command addParameterValue: 4294967295.
	command addParameterValue: 4294967295.
	
	self assert: command serialize equals: #[44 255 255 255 255 255 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:51'!
testSerializingCommandWithOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := PowerStbSetSwitchesStateCommand newWithReceiver: SatelliteTest powerSubsystem andId: 36.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[36 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSerializingCommandWithOneU32AndOneString8ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryWriteAddressCommand newWithReceiver: SatelliteTest memorySubsystem andId: 44.

	command addParameterValue: 1.
	command addParameterValue: 'Hello'.
	
	self assert: command serialize equals: #[44 0 0 0 1 5 72 101 108 108 111]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSerializingCommandWithOneU32ParameterShouldSerializeOK
	
	| command |
	
	command := ThermalSetMatrixKeyCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 32.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:20'!
testSerializingCommandWithTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadLongAddressCommand newWithReceiver: SatelliteTest memorySubsystem andId: 44.

	command addParameterValue: 1.
	command addParameterValue: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:01'!
testSerializingCommandWithoutParametersShouldSerializeCommandIdOnly
	
	| command |
	
	command := CommandTest thermalSubsystemTelemetryCommand.
	
	self assert: command serialize equals: #[1]! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log |
	
	log := ControllerLog new.
	
	log addRequest: 'telemetry' withSequenceNumber: 1.
	
	self assert: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'messageMovedToTheArchive' withSequenceNumber: 1.
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	log addRequest: 'expectedMessage' withSequenceNumber: 1.
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: 'expectedMessage'.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'requestMessage' withSequenceNumber: 1.
		
	"exercise"
	log addResponse: 'responseMessage' withSequenceNumber: 1.
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: 'requestMessage'.
	self assert: (logEntry response) equals: 'responseMessage'.
! !

TestCase subclass: #SatelliteControllerTest
	instanceVariableNames: 'clientSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/28/2013 18:10'!
testEncodingNameCommandRequestShouldReturnCorrectString

	| satelliteController nameCommand resultingByteArray |
	
	satelliteController := SatelliteController new.

	nameCommand :=  GetNameCommand newWithReceiver: (SatelliteTest memorySubsystem) andId: 0. 
	
	resultingByteArray := satelliteController encode: nameCommand withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[78 129 151 0 0 1 1 0]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/28/2013 18:13'!
testEncodingSetMatrixKeyRequestShouldReturnCorrectString

	| satelliteController command resultingByteArray |
	
	satelliteController := SatelliteController new.

	command :=  ThermalSetMatrixKeyCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 32.
	command addParameterValue: 1.
	
	resultingByteArray := satelliteController encode: command withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[225 246 60 0 0 1 3 32 0 0 0 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/28/2013 18:13'!
testEncodingTelemetryRequestShouldReturnCorrectString

	| satelliteController thermalTelCommand resultingByteArray |

	satelliteController := SatelliteController new.
	
	thermalTelCommand := ThermalTelemetryCommand newWithReceiver: SatelliteTest memorySubsystem andId: 1.

	resultingByteArray := satelliteController encode: thermalTelCommand withSequenceNumber: (SequenceNumber new).

	self assert: resultingByteArray equals: #[90 204 175 0 0 1 1 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/24/2013 23:34'!
testReceiveBeacon
	| satelliteController stream |
	
	satelliteController := SatelliteController new.
	
	stream := satelliteController radioStream.
	
	stream receiveData.
	
	satelliteController shutdown.
	
	self assert: (stream nextAvailable ) equals: 'ASDF'
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/28/2013 18:09'!
testSendGetNameCommand
	| satelliteController commandCall radioStream command |
	
	satelliteController := SatelliteController new.
	
	command := ThermalTelemetryCommand newWithReceiver: (SatelliteTest thermalSubsystem) andId: 1.

	commandCall := self encode: command withSequenceNumber: SequenceNumber new.

	radioStream := satelliteController radioStream.

	"radioStream nextPutAll: commandCall; flush."
	
	radioStream nextPutAll: #[44 110 127 0 0 1 0 0]; flush.
	
	radioStream receiveData.
	
	satelliteController shutdown.
	
	self assert: (radioStream nextAvailable ) equals: 'ASDF'
! !

TestCase subclass: #SatelliteSubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:19'!
test01WhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := Memory new.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:45'!
test02WhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.

	"verify"	
	self assert: (subsystem understands: 'name').
	self assert: (subsystem understands: 'telemetry').
	self assert: (subsystem understands: 'short_telemetry').
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:45'!
test03WhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem  |

	"setup"
	subsystem := SatelliteTest memorySubsystem.

	"verify"	
	self deny: (subsystem understands: 'notACommand').
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 20:03'!
test04ThermalShortTelemetryShouldReturnOK

	| subsystem expectedShortTelemetry shortTelemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	expectedShortTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	shortTelemetry:=	subsystem shortTelemetry. 

	"verify"	
	self assert: shortTelemetry = expectedShortTelemetry.

! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 20:07'!
test05ThermalTelemetryShouldReturnOK

	| subsystem expectedTelemetry telemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	data add: (Association key: 'radio_temp' value: 20).
	expectedTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	telemetry:= subsystem telemetry. 

	"verify"	
	self assert: telemetry = expectedTelemetry.

! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:20'!
memorySubsystem
	| memorySubsystem |

	memorySubsystem := Memory new.
	memorySubsystem setAttribute: 'free' withValue: 100.
	
	^ memorySubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:20'!
platformSubsystem
	| platformSubsystem |

	platformSubsystem := Platform new.
	platformSubsystem setAttribute: 'tick_count' withValue: 1000000.
	platformSubsystem setAttribute: 'current_mode' withValue: 1.
	
	^ platformSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:20'!
powerSubsystem
	| platformSubsystem |

	platformSubsystem := Power new.
	
	^ platformSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:27'!
satelliteWithAllSubsystems
	| subsystems |

	subsystems := Set new.
	subsystems add: self platformSubsystem.
	subsystems add: self memorySubsystem.
	subsystems add: self thermalSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:20'!
thermalSubsystem
	| thermalSubsystem |

	thermalSubsystem := Thermal new.
	thermalSubsystem setAttribute: 'battery_temp' withValue: 10.
	thermalSubsystem setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSubsystem! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 18:21'!
testDecodeThermalSubsystemNameCommand

	| satellite bytes getNameCommand commandEncoder decodedCommand |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.
	commandEncoder := CommandEncoder new.
	getNameCommand := GetNameCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 0.
	bytes := commandEncoder encodeWith: 'FFF' andSequenceNumber: 1 andCommand: getNameCommand.

	"exercise"	
	decodedCommand := satellite receive: bytes.

	"verify"	
	self assert: decodedCommand equals: getNameCommand.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:27'!
testGivenASatelliteWhenEmittingAShortBeaconItReturnsAShortBeacon

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"short_telemetry":[{"subsystem_id":"3","battery_temp":"10"}]}'.

	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/28/2013 19:19'!
testGivenASatelliteWithThermalSubsystemOnlyWhenEmittingABeaconTheBeaconContainsOnlyThermalTelemetry

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := Thermal newWithId: 3 andName: 'THERMAL'.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"telemetry":[{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 16:24'!
testGivenASatelliteWithTwoSubsystemsWhenEmittingABeaconTheBeaconContainsTwoTelemetryData

	| satellite expectedBeacon beacon |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.

	expectedBeacon := '{"telemetry":[{"subsystem_id":"1","free":"100"},{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

TestCase subclass: #SequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := SequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := SequenceNumber startingFrom: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := SequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := SequenceNumber startingFrom: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !
